==> google-cloud-bigquery-migration-0.2.1.tar.gz: google-cloud-bigquery-migration-0.2.1/google/cloud/bigquery_migration_v2alpha/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.migration_service import MigrationServiceClient
from .services.migration_service import MigrationServiceAsyncClient

from .types.migration_entities import MigrationSubtask
from .types.migration_entities import MigrationTask
from .types.migration_entities import MigrationWorkflow
from .types.migration_error_details import ErrorDetail
from .types.migration_error_details import ErrorLocation
from .types.migration_error_details import ResourceErrorDetail
from .types.migration_metrics import Point
from .types.migration_metrics import TimeInterval
from .types.migration_metrics import TimeSeries
from .types.migration_metrics import TypedValue
from .types.migration_service import CreateMigrationWorkflowRequest
from .types.migration_service import DeleteMigrationWorkflowRequest
from .types.migration_service import GetMigrationSubtaskRequest
from .types.migration_service import GetMigrationWorkflowRequest
from .types.migration_service import ListMigrationSubtasksRequest
from .types.migration_service import ListMigrationSubtasksResponse
from .types.migration_service import ListMigrationWorkflowsRequest
from .types.migration_service import ListMigrationWorkflowsResponse
from .types.migration_service import StartMigrationWorkflowRequest

__all__ = (
    "MigrationServiceAsyncClient",
    "CreateMigrationWorkflowRequest",
    "DeleteMigrationWorkflowRequest",
    "ErrorDetail",
    "ErrorLocation",
    "GetMigrationSubtaskRequest",
    "GetMigrationWorkflowRequest",
    "ListMigrationSubtasksRequest",
    "ListMigrationSubtasksResponse",
    "ListMigrationWorkflowsRequest",
    "ListMigrationWorkflowsResponse",
    "MigrationServiceClient",
    "MigrationSubtask",
    "MigrationTask",
    "MigrationWorkflow",
    "Point",
    "ResourceErrorDetail",
    "StartMigrationWorkflowRequest",
    "TimeInterval",
    "TimeSeries",
    "TypedValue",
)

==> google-cloud-bigquery-migration-0.3.0.tar.gz: google-cloud-bigquery-migration-0.3.0/google/cloud/bigquery_migration_v2alpha/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.migration_service import MigrationServiceClient
from .services.migration_service import MigrationServiceAsyncClient

from .types.assessment_task import AssessmentOrchestrationResultDetails
from .types.assessment_task import AssessmentTaskDetails
from .types.migration_entities import MigrationSubtask
from .types.migration_entities import MigrationTask
from .types.migration_entities import MigrationTaskOrchestrationResult
from .types.migration_entities import MigrationWorkflow
from .types.migration_error_details import ErrorDetail
from .types.migration_error_details import ErrorLocation
from .types.migration_error_details import ResourceErrorDetail
from .types.migration_metrics import Point
from .types.migration_metrics import TimeInterval
from .types.migration_metrics import TimeSeries
from .types.migration_metrics import TypedValue
from .types.migration_service import CreateMigrationWorkflowRequest
from .types.migration_service import DeleteMigrationWorkflowRequest
from .types.migration_service import GetMigrationSubtaskRequest
from .types.migration_service import GetMigrationWorkflowRequest
from .types.migration_service import ListMigrationSubtasksRequest
from .types.migration_service import ListMigrationSubtasksResponse
from .types.migration_service import ListMigrationWorkflowsRequest
from .types.migration_service import ListMigrationWorkflowsResponse
from .types.migration_service import StartMigrationWorkflowRequest
from .types.translation_task import BteqOptions
from .types.translation_task import DatasetReference
from .types.translation_task import Filter
from .types.translation_task import IdentifierSettings
from .types.translation_task import TeradataOptions
from .types.translation_task import TranslationFileMapping
from .types.translation_task import TranslationTaskDetails

__all__ = (
    "MigrationServiceAsyncClient",
    "AssessmentOrchestrationResultDetails",
    "AssessmentTaskDetails",
    "BteqOptions",
    "CreateMigrationWorkflowRequest",
    "DatasetReference",
    "DeleteMigrationWorkflowRequest",
    "ErrorDetail",
    "ErrorLocation",
    "Filter",
    "GetMigrationSubtaskRequest",
    "GetMigrationWorkflowRequest",
    "IdentifierSettings",
    "ListMigrationSubtasksRequest",
    "ListMigrationSubtasksResponse",
    "ListMigrationWorkflowsRequest",
    "ListMigrationWorkflowsResponse",
    "MigrationServiceClient",
    "MigrationSubtask",
    "MigrationTask",
    "MigrationTaskOrchestrationResult",
    "MigrationWorkflow",
    "Point",
    "ResourceErrorDetail",
    "StartMigrationWorkflowRequest",
    "TeradataOptions",
    "TimeInterval",
    "TimeSeries",
    "TranslationFileMapping",
    "TranslationTaskDetails",
    "TypedValue",
)
